# Feature Exploration Toolkit

Exploratory data analysis toolkit applicable to data exported by Nemea [ipfixprobe](https://github.com/CESNET/ipfixprobe).

[Documentation](https://docs.danieluhricek.cz/fet/)
